@@ -29,8 +29,19 @@ class Processor:
         self.zipy: bool = settings.get("zipy", False)
         self.hash: bool = settings.get("hash", False)
         self.verbose: bool = settings.get("verbose", False)
+        self.force: bool = settings.get("force", False)
 
-        self.processor_map = {"sass": (sass_minify, False), "css": (css_minify, False), "html": (html_minify, False), "svg": (svg_minify, False), "js": (js_minify, False), "png": (png_minify, True), "jpeg": (jpeg_minify, True)}
+        # fmt off
+        self.processor_map = {
+            "sass": (sass_minify, False),
+            "css": (css_minify, False),
+            "html": (html_minify, False),
+            "svg": (svg_minify, False),
+            "js": (js_minify, False),
+            "png": (png_minify, True),
+            "jpeg": (jpeg_minify, True)
+        }
+        # fmt on
 
         self.valid_extensions = [f".{ext}" for ext in self.processor_map.keys()]
         if self.verbose:
@@ -67,10 +78,10 @@ class Processor:
             if self.on_change:
                 input_mtime = os.path.getmtime(input_path)
                 output_mtime = os.path.getmtime(output_path)
-                if input_mtime == output_mtime:
-                    return True, False, True, f"File not changed ({input_mtime}), skipping"
-                elif output_mtime > input_mtime:
-                    return True, False, True, f"Destination file newer than input ({output_mtime}>{input_mtime}), skipping"
+                if not self.force and (input_mtime == output_mtime):
+                    return True, False, True, "File not changed, skipping"
+                elif not self.force and (output_mtime > input_mtime):
+                    return True, False, True, "Destination file newer than input, skipping"
         else:
             output_dir = os.path.dirname(output_path)
             if not os.path.isdir(output_dir):
